# SolverJs Community Contributing Guide

The goal of this document is to create a contribution process that:

* Encourages new contributions.
* Encourages contributors to remain involved.
* Avoids unnecessary processes and bureaucracy whenever possible.
* Creates a transparent decision making process that makes it clear how
contributors can be involved in decision making.

## Vocabulary

* A **Contributor** is any individual creating or commenting on an issue or pull request.
* A **Committer** is a subset of contributors who have been given write access to the repository.

## Logging Issues

Log an issue for any question or problem you might have. When in doubt, log an issue, and
any additional policies about what to include will be provided in the responses. The only
exception is security disclosures which should be sent privately.

Committers may direct you to another repository, ask for additional clarifications, and
add appropriate metadata before the issue is addressed.

Please be courteous and respectful. Every participant is expected to follow the
project's Code of Conduct.

## Contributions

Any change to resources in this repository must be through pull requests. This applies to all changes
to documentation, code, binary files, etc. Even long term committers and TC members must use
pull requests.

No pull request can be merged without being reviewed.

For non-trivial contributions, pull requests should sit for at least 36 hours to ensure that
contributors in other timezones have time to review. Consideration should also be given to
weekends and other holiday periods to ensure active committers all have reasonable time to
become involved in the discussion and review process if they wish.

## 🎉Contributing Guidelines 📝
- Thanks a Ton for Showing your Interest in Contributing to our Repository! Pull requests are Welcome. For Major Changes, Please Open an Issue first to Discuss What you Would Like to Change.

- To Start Contributing to this Repository, Follow the Below Guidelines:-

1. **Fork this Repository.**

2. **Clone your Forked Copy of The Project.**
   ```
   git clone https://github.com/<your_user_name>/solverjs.git
   ```

3. **Navigate to the Project Directory 📁.**
   ```
   cd solverjs
   ```
4. **Before Making any Changes in the Repository, Always Take a Pull from the Upstream Repository to Your Branch to Keep it Updated with The Remote Repository.**
   ```
   git pull upstream main
   ```
5. **Create a New Branch**.
   ```
   git checkout -b <your_branch_name>
   ```
6. **Make Necessary Changes that are Required.**

7. **Track Your Changes**
   ```
   git add .
   ```
8. **Commit your Changes.**
   ```
   git commit -m "Relevant message"
   ```
9. **Push the Commited Changes in Your Branch to Your Remote Repo.**
    ```
    git push -u origin <your_branch_name>
    ```
10. **Make The Pull Request (PR)** 🚀
11. Wooohoo! You have Successfully Made a PR to the Repo- solverjs 💥. Wait for your Submission to be Accepted and your PR to be Merged!.

<br/>
<hr />

## ✨Our Contributors!-

<a href="https://github.com/suryapratapsinghsuryavanshi/solverjs">
  <img src="https://contrib.rocks/image?repo=suryapratapsinghsuryavanshi/solverjs" />
</a>

## Becoming a Triager
[Open an issue in `solverjs` repo](https://github.com/suryapratapsinghsuryavanshi/solverjs/issues/new)
to request the triage role. State that you have read and agree to the
[Code of Conduct](Code-Of-Conduct.md) and details of the role.


## Becoming a Committer

All contributors who land a non-trivial contribution should be on-boarded in a timely manner,
and added as a committer, and be given write access to the repository.

Committers are expected to follow this policy and continue to send pull requests, go through
proper review, and have other committers merge their pull requests.